Notifications

# cs_comment, is_mention=False, status_change=None

    From: u1 u1
    To: u2@example.com
    Subject: [Comment] repo/name changeset cafe1234 "This changeset did something cl..." on brunch

    http://comment.org

    Comment on Changeset "This changeset did something clever which is hard to explain"

    Opinionated User (jsmith):

    This is the new 'comment'.

     - and here it ends indented.

    Changeset on http://example.com/repo_target branch brunch:
    "This changeset did something clever which is hard to explain" by u2 u3 (u2).

    View Comment: http://comment.org

| Comment on Changeset "This changeset did something clever which is hard to explain" |
| Opinionated User (jsmith) |
| This is the new 'comment'. - and here it ends indented. |
Changeset on http://example.com/repo_target branch brunch: "This changeset did something clever which is hard to explain" by u2 u3 (u2).
View Comment

# cs_comment, is_mention=True, status_change=None

    From: u1 u1
    To: u2@example.com
    Subject: [Comment] repo/name changeset cafe1234 "This changeset did something cl..." on brunch

    http://comment.org

    Mention in Comment on Changeset "This changeset did something clever which is hard to explain"

    Opinionated User (jsmith):

    This is the new 'comment'.

     - and here it ends indented.

    Changeset on http://example.com/repo_target branch brunch:
    "This changeset did something clever which is hard to explain" by u2 u3 (u2).

    View Comment: http://comment.org

| Mention in Comment on Changeset "This changeset did something clever which is hard to explain" |
| Opinionated User (jsmith) |
| This is the new 'comment'. - and here it ends indented. |
Changeset on http://example.com/repo_target branch brunch: "This changeset did something clever which is hard to explain" by u2 u3 (u2).
View Comment

# cs_comment, is_mention=False, status_change='Approved'

    From: u1 u1
    To: u2@example.com
    Subject: [Approved: Comment] repo/name changeset cafe1234 "This changeset did something cl..." on brunch

    http://comment.org

    Comment on Changeset "This changeset did something clever which is hard to explain"

    Opinionated User (jsmith):

    Status change: Approved

    This is the new 'comment'.

     - and here it ends indented.

    Changeset on http://example.com/repo_target branch brunch:
    "This changeset did something clever which is hard to explain" by u2 u3 (u2).

    View Comment: http://comment.org

| Comment on Changeset "This changeset did something clever which is hard to explain" |
| Opinionated User (jsmith) |
| Status change: Approved |
| This is the new 'comment'. - and here it ends indented. |
Changeset on http://example.com/repo_target branch brunch: "This changeset did something clever which is hard to explain" by u2 u3 (u2).
View Comment

# cs_comment, is_mention=True, status_change='Approved'

    From: u1 u1
    To: u2@example.com
    Subject: [Approved: Comment] repo/name changeset cafe1234 "This changeset did something cl..." on brunch

    http://comment.org

    Mention in Comment on Changeset "This changeset did something clever which is hard to explain"

    Opinionated User (jsmith):

    Status change: Approved

    This is the new 'comment'.

     - and here it ends indented.

    Changeset on http://example.com/repo_target branch brunch:
    "This changeset did something clever which is hard to explain" by u2 u3 (u2).

    View Comment: http://comment.org

| Mention in Comment on Changeset "This changeset did something clever which is hard to explain" |
| Opinionated User (jsmith) |
| Status change: Approved |
| This is the new 'comment'. - and here it ends indented. |
Changeset on http://example.com/repo_target branch brunch: "This changeset did something clever which is hard to explain" by u2 u3 (u2).
View Comment

# message

    From: u1 u1
    To: u2@example.com
    Subject: Test Message

    This is the 'body' of the "test" message
     - nothing interesting here except indentation.

| Message |
This is the 'body' of the "test" message - nothing interesting here except indentation.

# registration

    From: u1 u1
    To: u2@example.com
    Subject: New user newbie registered

    http://newbie.org

    New User Registration

    Username: newbie

    Full Name: New Full Name

    Email: new@email.com

    View User Profile: http://newbie.org

| New User Registration |
Username: | newbie
Full Name: | New Full Name
Email: | new@email.com
View User Profile

# pull_request, is_mention=False

    From: u1 u1
    To: u2@example.com
    Subject: [Review] repo/name PR #7 "The Title" from devbranch by u2

    http://pr.org/7

    Added as Reviewer of Pull Request #7 "The Title" by Requesting User (root)

    Pull request #7 "The Title" by u2 u3 (u2)
    from https://dev.org/repo branch devbranch
    to http://mainline.com/repo branch trunk

    Description:

    This PR is 'awesome' because it does
     - please approve indented!

    Changesets:

    Introduce one and two
    Make one plus two equal tree

    View Pull Request: http://pr.org/7

| Added as Reviewer of Pull Request #7 "The Title" by Requesting User (root) |
Pull request #7 "The Title" by u2 u3 (u2). from https://dev.org/repo branch devbranch to http://mainline.com/repo branch trunk
Description:
| This PR is 'awesome' because it does <stuff> - please approve indented! |
Changesets:
Introduce one and two Make one plus two equal tree
View Pull Request

# pull_request, is_mention=True

    From: u1 u1
    To: u2@example.com
    Subject: [Review] repo/name PR #7 "The Title" from devbranch by u2

    http://pr.org/7

    Mention on Pull Request #7 "The Title" by Requesting User (root)

    Pull request #7 "The Title" by u2 u3 (u2)
    from https://dev.org/repo branch devbranch
    to http://mainline.com/repo branch trunk

    Description:

    This PR is 'awesome' because it does
     - please approve indented!

    Changesets:

    Introduce one and two
    Make one plus two equal tree

    View Pull Request: http://pr.org/7

| Mention on Pull Request #7 "The Title" by Requesting User (root) |
Pull request #7 "The Title" by u2 u3 (u2). from https://dev.org/repo branch devbranch to http://mainline.com/repo branch trunk
Description:
| This PR is 'awesome' because it does <stuff> - please approve indented! |
Changesets:
Introduce one and two Make one plus two equal tree
View Pull Request

# pull_request_comment, is_mention=False, status_change=None, closing_pr=False

    From: u1 u1
    To: u2@example.com
    Subject: [Comment] repo/name PR #7 "The Title" from devbranch by u2

    http://pr.org/comment

    Comment on Pull Request #7 "The Title"

    Opinionated User (jsmith):

    Me too!

     - and indented on second line

    Pull request #7 "The Title" by u2 u3 (u2)
    from https://dev.org/repo branch devbranch
    to http://mainline.com/repo branch trunk

    View Comment: http://pr.org/comment

| Comment on Pull Request #7 "The Title" |
| Opinionated User (jsmith) |
| Me too! - and indented on second line |
Pull request #7 "The Title" by u2 u3 (u2). from https://dev.org/repo branch devbranch to http://mainline.com/repo branch trunk:
View Comment

# pull_request_comment, is_mention=True, status_change=None, closing_pr=False

    From: u1 u1
    To: u2@example.com
    Subject: [Comment] repo/name PR #7 "The Title" from devbranch by u2

    http://pr.org/comment

    Mention in Comment on Pull Request #7 "The Title"

    Opinionated User (jsmith):

    Me too!

     - and indented on second line

    Pull request #7 "The Title" by u2 u3 (u2)
    from https://dev.org/repo branch devbranch
    to http://mainline.com/repo branch trunk

    View Comment: http://pr.org/comment

| Mention in Comment on Pull Request #7 "The Title" |
| Opinionated User (jsmith) |
| Me too! - and indented on second line |
Pull request #7 "The Title" by u2 u3 (u2). from https://dev.org/repo branch devbranch to http://mainline.com/repo branch trunk:
View Comment

# pull_request_comment, is_mention=False, status_change='Under Review', closing_pr=False

    From: u1 u1
    To: u2@example.com
    Subject: [Under Review: Comment] repo/name PR #7 "The Title" from devbranch by u2

    http://pr.org/comment

    Comment on Pull Request #7 "The Title"

    Opinionated User (jsmith):

    Status change: Under Review

    Me too!

     - and indented on second line

    Pull request #7 "The Title" by u2 u3 (u2)
    from https://dev.org/repo branch devbranch
    to http://mainline.com/repo branch trunk

    View Comment: http://pr.org/comment

| Comment on Pull Request #7 "The Title" |
| Opinionated User (jsmith) |
| Status change: Under Review |
| Me too! - and indented on second line |
Pull request #7 "The Title" by u2 u3 (u2). from https://dev.org/repo branch devbranch to http://mainline.com/repo branch trunk:
View Comment

# pull_request_comment, is_mention=True, status_change='Under Review', closing_pr=False

    From: u1 u1
    To: u2@example.com
    Subject: [Under Review: Comment] repo/name PR #7 "The Title" from devbranch by u2

    http://pr.org/comment

    Mention in Comment on Pull Request #7 "The Title"

    Opinionated User (jsmith):

    Status change: Under Review

    Me too!

     - and indented on second line

    Pull request #7 "The Title" by u2 u3 (u2)
    from https://dev.org/repo branch devbranch
    to http://mainline.com/repo branch trunk

    View Comment: http://pr.org/comment

| Mention in Comment on Pull Request #7 "The Title" |
| Opinionated User (jsmith) |
| Status change: Under Review |
| Me too! - and indented on second line |
Pull request #7 "The Title" by u2 u3 (u2). from https://dev.org/repo branch devbranch to http://mainline.com/repo branch trunk:
View Comment

# pull_request_comment, is_mention=False, status_change=None, closing_pr=True

    From: u1 u1
    To: u2@example.com
    Subject: [Closing: Comment] repo/name PR #7 "The Title" from devbranch by u2

    http://pr.org/comment

    Pull Request #7 "The Title" Closed

    Opinionated User (jsmith):

    The pull request has been closed.

    Me too!

     - and indented on second line

    Pull request #7 "The Title" by u2 u3 (u2)
    from https://dev.org/repo branch devbranch
    to http://mainline.com/repo branch trunk

    View Comment: http://pr.org/comment

| Pull Request #7 "The Title" Closed |
| Opinionated User (jsmith) |
| The pull request has been closed. |
| Me too! - and indented on second line |
Pull request #7 "The Title" by u2 u3 (u2). from https://dev.org/repo branch devbranch to http://mainline.com/repo branch trunk:
View Comment

# pull_request_comment, is_mention=True, status_change=None, closing_pr=True

    From: u1 u1
    To: u2@example.com
    Subject: [Closing: Comment] repo/name PR #7 "The Title" from devbranch by u2

    http://pr.org/comment

    Mention in Comment on Pull Request #7 "The Title"

    Opinionated User (jsmith):

    The pull request has been closed.

    Me too!

     - and indented on second line

    Pull request #7 "The Title" by u2 u3 (u2)
    from https://dev.org/repo branch devbranch
    to http://mainline.com/repo branch trunk

    View Comment: http://pr.org/comment

| Mention in Comment on Pull Request #7 "The Title" |
| Opinionated User (jsmith) |
| The pull request has been closed. |
| Me too! - and indented on second line |
Pull request #7 "The Title" by u2 u3 (u2). from https://dev.org/repo branch devbranch to http://mainline.com/repo branch trunk:
View Comment

# pull_request_comment, is_mention=False, status_change='Under Review', closing_pr=True

    From: u1 u1
    To: u2@example.com
    Subject: [Under Review, Closing: Comment] repo/name PR #7 "The Title" from devbranch by u2

    http://pr.org/comment

    Pull Request #7 "The Title" Closed

    Opinionated User (jsmith):

    Status change: Under Review

    The pull request has been closed.

    Me too!

     - and indented on second line

    Pull request #7 "The Title" by u2 u3 (u2)
    from https://dev.org/repo branch devbranch
    to http://mainline.com/repo branch trunk

    View Comment: http://pr.org/comment

| Pull Request #7 "The Title" Closed |
| Opinionated User (jsmith) |
| Status change: Under Review The pull request has been closed. |
| Me too! - and indented on second line |
Pull request #7 "The Title" by u2 u3 (u2). from https://dev.org/repo branch devbranch to http://mainline.com/repo branch trunk:
View Comment

# pull_request_comment, is_mention=True, status_change='Under Review', closing_pr=True

    From: u1 u1
    To: u2@example.com
    Subject: [Under Review, Closing: Comment] repo/name PR #7 "The Title" from devbranch by u2

    http://pr.org/comment

    Mention in Comment on Pull Request #7 "The Title"

    Opinionated User (jsmith):

    Status change: Under Review

    The pull request has been closed.

    Me too!

     - and indented on second line

    Pull request #7 "The Title" by u2 u3 (u2)
    from https://dev.org/repo branch devbranch
    to http://mainline.com/repo branch trunk

    View Comment: http://pr.org/comment

| Mention in Comment on Pull Request #7 "The Title" |
| Opinionated User (jsmith) |
| Status change: Under Review The pull request has been closed. |
| Me too! - and indented on second line |
Pull request #7 "The Title" by u2 u3 (u2). from https://dev.org/repo branch devbranch to http://mainline.com/repo branch trunk:
View Comment

# TYPE_PASSWORD_RESET

    From: u1 u1
    To: john@doe.com
    Subject: Password reset link

    Password Reset Request

    Hello John Doe,

    We have received a request to reset the password for your account.

    To set a new password, click the following link:

    http://reset.com/decbf64715098db5b0bd23eab44bd792670ab746

    Should you not be able to use the link above, please type the following code into the password reset form:
    decbf64715098db5b0bd23eab44bd792670ab746

    If it weren't you who requested the password reset, just disregard this message.

| Password Reset Request |
Hello John Doe,
We have received a request to reset the password for your account.
To set a new password, click the following link: http://reset.com/decbf64715098db5b0bd23eab44bd792670ab746 Should you not be able to use the link above, please type the following code into the password reset form: `decbf64715098db5b0bd23eab44bd792670ab746`
If it weren't you who requested the password reset, just disregard this message.